@@ -65,7 +65,7 @@ class KSampleTest(ABC):
 
         Parameters
         ----------
-        *args : ndarray
+        *args : ndarray of float
             Variable length input data matrices. All inputs must have the same
             number of dimensions. That is, the shapes must be `(n, p)` and
             `(m, p)`, ... where `n`, `m`, ... are the number of samples and `p` is
@@ -84,7 +84,7 @@ class KSampleTest(ABC):
 
         Parameters
         ----------
-        *args : ndarray
+        *args : ndarray of float
             Variable length input data matrices. All inputs must have the same
             number of dimensions. That is, the shapes must be `(n, p)` and
             `(m, p)`, ... where `n`, `m`, ... are the number of samples and `p` is
