@@ -19,6 +19,18 @@ class TestEnergy:
         assert_almost_equal(stat, obs_stat, decimal=1)
         assert_almost_equal(pvalue, obs_pvalue, decimal=1)
 
+    @pytest.mark.parametrize(
+        "n, obs_stat, obs_pvalue",
+        [(100, 8.24e-5, 0.001)],
+    )
+    def test_rep(self, n, obs_stat, obs_pvalue):
+        x, y = rot_ksamp("linear", n, 1, k=2)
+        stat, pvalue = Energy().test(x, y, auto=False, random_state=2)
+        stat2, pvalue2 = Energy().test(x, y, auto=False, random_state=2)
+
+        assert stat == stat2
+        assert pvalue == pvalue2
+
 
 class TestEnergyTypeIError:
     def test_oned(self):
